from setuptools import setup

setup(name='sayar-distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['sayar-distributions'],
      author="Sayar Banerjee",
      zip_safe=False)
